#!/bin/bash
#
#	Grab a video stream from an IP camera into a temp file.
#	Inject an 'Events' record into the ZM Database.
#	Create the directory in the zm storage area
#	Move the mp4 to the right place
#
#	Call with the Camera Id number as arg1:
#
#	zmrecord.sh 12
#
#
#	You might have to install mediainfo which I use to grab
#	the frame count.
#
#	Version	0.1	-	18/ 9/18	First hack
#	Version	0.2	-	19/ 9/18	Read monitor guff from DB
#	Version	0.3	-	19/ 9/18	Set StorageId in DB
#
#
#########################################
# 	Recording chunk time in seconds
#	This script will record for this number of seconds at a time
#	600 (10 minutes) is what I use.
RECORD_TIME=600
#
#########################################

if [ $# -ne 1 ]
then
	echo "Syntax: $0 <Monitor Id>"
	exit 1
fi

MONITOR_ID=$1

IFS=$'\t'
read -r WIDTH HEIGHT READPATH STORAGEID <<< `mysql -NBqr zm -e "select Width,Height,Path,StorageId from Monitors where Id=$MONITOR_ID"`
read -r STORAGE <<< `mysql -NBqr zm -e "select Path from Storage where Id=$STORAGEID"`
STORE_PATH=$STORAGE/$MONITOR_ID

if [ -z "$READPATH" -o -z "$STORE_PATH" ]
then
	echo "$0 Monitor Data Error. Got: Width $WIDTH Height $HEIGHT ReadPath $READPATH StorePath $STORE_PATH"
	exit 1
fi

tmpfile=$(mktemp $STORE_PATH/Rec-XXXXXX.mp4)

while true
do
	#
	#	Record
	START_TIME=`date --rfc-3339=seconds`
	ffmpeg -y -loglevel quiet -t $RECORD_TIME -i "$READPATH" -c:v copy $tmpfile
	END_TIME=`date --rfc-3339=seconds`

	FILESIZE=$(stat -c%s "$tmpfile")
	FRAMES=`mediainfo --Output="Video;%FrameCount%" $tmpfile`

	if [ ${FRAMES:=0} -gt 0 ] && [ ${FILESIZE:=0} -gt 0 ]
	then
		#	
		#	Inject into ZM database
		THIS_ID=`mysql -NBqr zm <<-EOF
			INSERT INTO Events (MonitorId,StorageId,Name,Cause,StartTime,EndTime,Width,Height,Length,Frames,Videoed,DiskSpace,Scheme,StateId,AlarmFrames,SaveJPEGs,Notes)
			values ($MONITOR_ID,"$STORAGEID","New Event","Continuous","$START_TIME","$END_TIME",$WIDTH,$HEIGHT,$RECORD_TIME,$FRAMES,1,$FILESIZE,"Medium",1,0,0,"Injected from ffmpeg capture");
			SET @last_id = LAST_INSERT_ID();
			UPDATE Events SET Name=CONCAT("Event-",@last_id),DefaultVideo=CONCAT(@last_id,"-video.mp4") where Id=@last_id;
			SELECT @last_id;
		EOF`
		if [ "$THIS_ID" -le 0 ]
		then
			echo Woops. Something went wrong with the Mysql injection
			exit 1
		fi
		#
		#	Move recording to the right place
		THIS_PATH=$STORE_PATH/`date --rfc-3339=date`/$THIS_ID
		mkdir -p $THIS_PATH
		mv -f $tmpfile $THIS_PATH/$THIS_ID-video.mp4
		chown -R www-data.www-data $THIS_PATH
		#
	else
		# Hmmm... zero length recording. Clean it up
		rm -f $tmpfile
	fi
done
